
Change Log
===========

0.3.1 released 2010-11-24
--------------------------

* fixed testing on windows
* ``settings.email.is_live = False`` will now also prevent a connection from being opened
* added ``prefix_relative_url()`` to routing.py

